You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by pr...@apache.org on 2006/02/20 17:39:56 UTC

svn commit: r379155 - in /webservices/axis/trunk/c/src/transport/axis3: HTTPChannel/HTTPChannel.cpp HTTPTransportException.cpp

Author: prestonf
Date: Mon Feb 20 08:39:54 2006
New Revision: 379155

URL: http://svn.apache.org/viewcvs?rev=379155&view=rev
Log:
Correcting 'receving' to 'receiving'.

Modified:
    webservices/axis/trunk/c/src/transport/axis3/HTTPChannel/HTTPChannel.cpp
    webservices/axis/trunk/c/src/transport/axis3/HTTPTransportException.cpp

Modified: webservices/axis/trunk/c/src/transport/axis3/HTTPChannel/HTTPChannel.cpp
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/c/src/transport/axis3/HTTPChannel/HTTPChannel.cpp?rev=379155&r1=379154&r2=379155&view=diff
==============================================================================
--- webservices/axis/trunk/c/src/transport/axis3/HTTPTransportException.cpp (original)
+++ webservices/axis/trunk/c/src/transport/axis3/HTTPTransportException.cpp Mon Feb 20 08:39:54 2006
@@ -122,7 +122,7 @@
         case SERVER_TRANSPORT_TIMEOUT_EXPIRED:
 		{
             m_sMessageForExceptionCode = "HTTPTransportException:Channel error connection " \
-                "timeout before receving";
+                "timeout before receiving";
             break;
 		}
--- webservices/axis/trunk/c/src/transport/axis3/HTTPChannel/HTTPChannel.cpp (original)
+++ webservices/axis/trunk/c/src/transport/axis3/HTTPChannel/HTTPChannel.cpp Mon Feb 20 08:39:54 2006
@@ -227,8 +227,8 @@
     if( iTimeoutStatus == 0)
     {
         // Timeout expired - select timeout expired.
-        // Channel error connection timeout before receving
-        m_LastError = "Channel error: connection timed out before receving";
+        // Channel error connection timeout before receiving
+        m_LastError = "Channel error: connection timed out before receiving";
 
         throw HTTPTransportException( SERVER_TRANSPORT_TIMEOUT_EXPIRED, 
                                       (char *) m_LastError.c_str());

Modified: webservices/axis/trunk/c/src/transport/axis3/HTTPTransportException.cpp
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/c/src/transport/axis3/HTTPTransportException.cpp?rev=379155&r1=379154&r2=379155&view=diff
==============================================================================